@@ -36,6 +36,8 @@
 #include <QDateTime>
 #include <QByteArray>
 #include <QDebug>
+#include <QProcess>
+#include <QSettings>
 
 #ifdef DISABLE_GUI
 #include <QCoreApplication>
@@ -57,6 +59,7 @@ const int UNLEN = 256;
 #ifdef Q_WS_MAC
 #include <CoreServices/CoreServices.h>
 #include <Carbon/Carbon.h>
+#include <Cocoa/Cocoa.h>
 #endif
 
 #ifndef Q_WS_WIN
@@ -77,6 +80,10 @@ const int UNLEN = 256;
 #endif
 #endif // DISABLE_GUI
 
+#ifdef Q_WS_WIN
+#include <QDesktopServices>
+#endif
+
 using namespace libtorrent;
 
 const int MAX_FILENAME_LENGTH = 255;
@@ -106,7 +113,9 @@ QString misc::QDesktopServicesDataLocation() {
   return result;
 #else
 #ifdef Q_WS_MAC
-  // http://developer.apple.com/documentation/Carbon/Reference/Folder_Manager/Reference/reference.html
+  // http://developer.apple.com/library/mac/#documentation/Cocoa/Reference/Foundation/Miscellaneous/Foundation_Functions/Reference/reference.html
+  NSArray *paths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
+  NSString *dataDirectory =
   FSRef ref;
   OSErr err = FSFindFolder(kUserDomain, kApplicationSupportFolderType, false, &ref);
   if (err)
@@ -154,9 +163,69 @@ QString misc::QDesktopServicesCacheLocation() {
 #endif
 }
 
+QString misc::QDesktopServicesDownloadLocation() {
+#ifdef Q_WS_WIN
+  // TODO: Use IKnownFolderManager to get path of FOLDERID_Downloads
+  // instead of hardcoding "Downloads"
+  // Unfortunately, this would break compatibility with WinXP
+  return QDir(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation)).absoluteFilePath(tr("Downloads"));
+#endif
+
+#ifdef Q_WS_X11
+  QString save_path;
+  // Default save path on Linux
+  QString config_path = QString::fromLocal8Bit(qgetenv("XDG_CONFIG_HOME").constData());
+  if (config_path.isEmpty())
+    config_path = QDir::home().absoluteFilePath(".config");
+
+  QString user_dirs_file = config_path + "/user-dirs.dirs";
+  if (QFile::exists(user_dirs_file)) {
+    QSettings settings(user_dirs_file, QSettings::IniFormat);
+    QString xdg_download_dir = settings.value("XDG_DOWNLOAD_DIR").toString();
+    if (!xdg_download_dir.isEmpty()) {
+      // Resolve $HOME environment variables
+      xdg_download_dir.replace("$HOME", QDir::homePath());
+      save_path = xdg_download_dir;
+      qDebug() << Q_FUNC_INFO << "SUCCESS: Using XDG path for downloads: " << save_path;
+    }
+  }
+
+  // Fallback
+  if (!save_path.isEmpty() && !QFile::exists(save_path)) {
+    QDir().mkpath(save_path);
+  }
+
+  if (save_path.isEmpty() || !QFile::exists(save_path)) {
+    save_path = QDir::home().absoluteFilePath(tr("Downloads"));
+    qDebug() << Q_FUNC_INFO << "using" << save_path << "as fallback since the XDG detection did not work";
+  }
+
+  return save_path;
+#endif
+
+#ifdef Q_WS_MAC
+  NSArray *paths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
+  NSString *applicationDirectory = [paths objectAtIndex:0];
+  NSRange range;
+  range.location = 0;
+  range.length = [applicationDirectory length];
+  QString path(range.length, QChar(0));
+
+  unichar *chars = new unichar[range.location];
+  [nsstr getCharacters:chars range:range];
+  QString path = QString::fromUtf16(chars, range.length);
+  delete chars;
+  path += QLatin1Char('/') + qApp->applicationName();
+  return path;
+#endif
+
+  // Fallback
+  return QDir::home().absoluteFilePath(tr("Downloads"));
+}
+
 long long misc::freeDiskSpaceOnPath(QString path) {
   if(path.isEmpty()) return -1;
-  path = path.replace("\\", "/");
+  path.replace("\\", "/");
   QDir dir_path(path);
   if(!dir_path.exists()) {
     QStringList parts = path.split("/");
@@ -167,6 +236,7 @@ long long misc::freeDiskSpaceOnPath(QString path) {
     if(!dir_path.exists()) return -1;
   }
   Q_ASSERT(dir_path.exists());
+
 #ifndef Q_WS_WIN
   unsigned long long available;
   struct statfs stats;
@@ -194,7 +264,7 @@ long long misc::freeDiskSpaceOnPath(QString path) {
   {
     ULARGE_INTEGER bytesFree, bytesTotal;
     unsigned long long *ret;
-    if (pGetDiskFreeSpaceEx((LPCTSTR)path.utf16(), &bytesFree, &bytesTotal, NULL)) {
+    if (pGetDiskFreeSpaceEx((LPCTSTR)(QDir::toNativeSeparators(dir_path.path())).utf16(), &bytesFree, &bytesTotal, NULL)) {
       ret = (unsigned long long*)&bytesFree;
       return *ret;
     } else {
@@ -300,7 +370,7 @@ void misc::shutdownComputer(bool sleep) {
 
   if (GetLastError() != ERROR_SUCCESS)
     return;
-  bool ret;
+
   if(sleep)
     SetSuspendState(false, false, false);
   else
@@ -514,15 +584,15 @@ QString misc::updateLabelInSavePath(QString defaultSavePath, QString save_path,
 
 QString misc::toValidFileSystemName(QString filename) {
   qDebug("toValidFSName: %s", qPrintable(filename));
-  filename = filename.replace("\\", "/").trimmed();
+  filename.replace("\\", "/").trimmed();
   const QRegExp regex("[/:?\"*<>|]");
-  filename = filename.replace(regex, " ").trimmed();
+  filename.replace(regex, " ").trimmed();
   qDebug("toValidFSName, result: %s", qPrintable(filename));
   return filename;
 }
 
 bool misc::isValidFileSystemName(QString filename) {
-  filename = filename.replace("\\", "/").trimmed();
+  filename.replace("\\", "/").trimmed();
   if(filename.isEmpty()) return false;
   const QRegExp regex("[/:?\"*<>|]");
   if(filename.contains(regex))
@@ -548,9 +618,36 @@ QPoint misc::screenCenter(QWidget *win) {
 }
 #endif
 
+/**
+ * Detects the version of python by calling
+ * "python --version" and parsing the output.
+ */
+int misc::pythonVersion() {
+  static int version = -1;
+  if (version < 0) {
+    QProcess python_proc;
+    python_proc.start("python", QStringList() << "--version", QIODevice::ReadOnly);
+    if (!python_proc.waitForFinished()) return -1;
+    if (python_proc.exitCode() < 0) return -1;
+    QByteArray output = python_proc.readAllStandardOutput();
+    if (output.isEmpty())
+      output = python_proc.readAllStandardError();
+    const QByteArray version_str = output.split(' ').last();
+    qDebug() << "Python version is:" << version_str.trimmed();
+    if (version_str.startsWith("3."))
+      version = 3;
+    else
+      version = 2;
+  }
+  return version;
+}
+
 QString misc::searchEngineLocation() {
+  QString folder = "nova";
+  if (pythonVersion() >= 3)
+    folder = "nova3";
   const QString location = QDir::cleanPath(QDesktopServicesDataLocation()
-                                           + QDir::separator() + "nova");
+                                           + QDir::separator() + folder);
   QDir locationDir(location);
   if(!locationDir.exists())
     locationDir.mkpath(locationDir.absolutePath());
@@ -724,7 +821,7 @@ QString misc::expandPath(QString path) {
     if(path[0] == '~' ) return QDir::homePath();
   }
   if(path[0] == '~' && path[1] == QDir::separator()) {
-    path = path.replace(0, 1, QDir::homePath());
+    path.replace(0, 1, QDir::homePath());
   } else {
     if(QDir::isAbsolutePath(path)) {
       path = QDir(path).absolutePath();
