@@ -88,7 +88,7 @@ public:
 
   static inline QString removeLastPathPart(QString path) {
     if(path.isEmpty()) return path;
-    path = path.replace("\\", "/");
+    path.replace("\\", "/");
     QStringList tmp = path.split("/");
     tmp.removeLast();
     return tmp.join("/");
@@ -145,12 +145,14 @@ public:
   /* Ported from Qt4 to drop dependency on QtGui */
   static QString QDesktopServicesDataLocation();
   static QString QDesktopServicesCacheLocation();
+  static QString QDesktopServicesDownloadLocation();
   /* End of Qt4 code */
 
 #ifndef DISABLE_GUI
   // Get screen center
   static QPoint screenCenter(QWidget *win);
 #endif
+  static int pythonVersion();
   static QString searchEngineLocation();
   static QString BTBackupLocation();
   static QString cacheLocation();
